{
	"name" : "Airport",
	"author" : "Tiny",
	"version" : "1.0",
	"depends" : ["base", "product"],
	"description": "Sample module to manage airport, flights and hostels",
	"init_xml" : [],
	"update_xml" : ["custom_view.xml", "custom_report.xml"],
	"category" : "Enterprise Specific Modules/Travel Agencies",
	"active": False,
	"installable": False
}
